import { HtmlRendererOptions, Highlighter, HighlighterOptions as HighlighterOptions$1 } from 'shiki';

type TLineOptions = NonNullable<HtmlRendererOptions['lineOptions']>;
interface ITransformerResult {
    code: string;
    lineOptions: TLineOptions;
}
type TPostTransformerResult = string | undefined;
interface ITransformerOptions {
    code: string;
    lang: string;
}
type TPreTransformer = (options: ITransformerOptions) => ITransformerResult;
type TPostTransformerHandler = (options: ITransformerOptions) => TPostTransformerResult;
interface IRangeTransformerOptions {
    tagRegExp?: RegExp;
}
interface ITransformer {
    name: string;
    preTransformer?: TPreTransformer;
    postTransformer?: TPostTransformerHandler;
}

interface ITransformerDiffOptions extends IRangeTransformerOptions {
    /**
   * Class for added lines
   */
    classLineAdd?: string;
    /**
     * Class for removed lines
     */
    classLineRemove?: string;
    /**
     * Class added to the <pre> element when the current code has diff
     */
    classActivePre?: string;
}
declare function createTransformerDiff(options?: ITransformerDiffOptions): ITransformer;

interface ITransformerFocusOptions extends IRangeTransformerOptions {
    /**
   * Class for focused lines
   */
    classActiveLine?: string;
    /**
    * Class added to the root element when the code has focused lines
    */
    classActivePre?: string;
}
declare function createTransformerFocus(options?: ITransformerFocusOptions): ITransformer;

interface ITransformerHighlightOptions extends IRangeTransformerOptions {
    classActivePre?: string;
    classActiveLine?: string;
}
declare function createTransformerHighlight(options?: ITransformerHighlightOptions): ITransformer;

interface ITransformerErrorLevelOptions extends IRangeTransformerOptions {
    classMap?: Record<string, string | string[]>;
    /**
     * Class added to the <pre> element when the current code has diff
     */
    classActivePre?: string;
}
declare function createTransformerErrorLevel(options?: ITransformerErrorLevelOptions): ITransformer;

declare function createTransformerLineNumber(): ITransformer;

declare function addClass(code: string, classes: string | string[], tag?: string): string;

declare function createRangeTransformer(classMap: Record<string, string | string[]>, options?: IRangeTransformerOptions): TPreTransformer;

/**
 * Defines a transformer.
 */
declare function defineTransformer(transformer: ITransformer): ITransformer;
/**
 * Transforms code through the given transformer.
 */
declare function transformer(transformers: ITransformer[], code: string, lang: string): ITransformerResult;
/**
 * Transforms final code through the given Transformers.
 */
declare function postTransformer(transformers: ITransformer[], code: string, lang: string): string;

interface HighlighterOptions extends HighlighterOptions$1 {
    transformers?: ITransformer[];
}
declare function getHighlighter(options?: HighlighterOptions): Promise<Highlighter>;

export { IRangeTransformerOptions, ITransformer, ITransformerDiffOptions, ITransformerErrorLevelOptions, ITransformerFocusOptions, ITransformerHighlightOptions, ITransformerOptions, ITransformerResult, TLineOptions, TPostTransformerHandler, TPostTransformerResult, TPreTransformer, addClass, createRangeTransformer, createTransformerDiff, createTransformerErrorLevel, createTransformerFocus, createTransformerHighlight, createTransformerLineNumber, defineTransformer, getHighlighter, postTransformer, transformer };
